@@ -1,6 +1,6 @@
 ################################################################################
 #
-#  Copyright (C) 2002-2006  Travis Shirk <travis@pobox.com>
+#  Copyright (C) 2002-2007  Travis Shirk <travis@pobox.com>
 #  Copyright (C) 2001  Ryan Finne <ryan@finnie.org>
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -854,8 +854,19 @@ class DateFrame(TextFrame):
            self.header.id = "TDOR";
        elif self.header.minorVersion == 3 and self.header.id == "TDOR":
            self.header.id = OBSOLETE_ORIG_RELEASE_FID;
+       elif self.header.minorVersion == 3 and self.header.id == "TDEN":
+           TRACE_MSG('Converting TDEN to TXXX(Encoding time) frame')
+           self.header.id = "TXXX";
+           self.description = "Encoding time";
+           data = self.encoding +\
+                  self.description.encode(id3EncodingToString(self.encoding)) +\
+                  self.getTextDelim() +\
+                  self.date_str.encode(id3EncodingToString(self.encoding));
+           return self.assembleFrame(data)
+
        elif self.header.minorVersion == 3 and self.header.id[:2] == "TD":
-           self.header.id = OBSOLETE_YEAR_FID;
+           if self.header.id not in ['TDEN', 'TDLY', 'TDTG']:
+              self.header.id = OBSOLETE_YEAR_FID;
 
        data = self.encoding +\
               self.date_str.encode(id3EncodingToString(self.encoding));
@@ -902,6 +913,16 @@ class UserTextFrame(TextFrame):
       TRACE_MSG("UserTextFrame text: %s" % self.text);
 
    def render(self):
+      if self.header.minorVersion == 4:
+         if self.description.lower() == 'tagging time':
+            TRACE_MSG("Converting TXXX(%s) to TDTG frame)" % self.description)
+            return ""
+         if self.description.lower() == 'encoding time':
+            TRACE_MSG("Converting TXXX(%s) to TDEN frame" % self.description)
+            self.header.id = 'TDEN'
+            data = self.encoding +\
+                   self.text.encode(id3EncodingToString(self.encoding))
+            return self.assembleFrame(data);
       data = self.encoding +\
              self.description.encode(id3EncodingToString(self.encoding)) +\
              self.getTextDelim() +\
@@ -1741,14 +1762,16 @@ class FrameSet(list):
             break;
 
          # Frame data.
-         TRACE_MSG("FrameSet: Reading %d (0x%X) bytes of data from byte "\
-                   "pos %d (0x%X)" % (frameHeader.dataSize,
-                                      frameHeader.dataSize, tagBuffer.tell(),
-                                      tagBuffer.tell()));
-         data = tagBuffer.read(frameHeader.dataSize);
-         TRACE_MSG("FrameSet: %d bytes of data read" % len(data));
+         if frameHeader.dataSize:
+             TRACE_MSG("FrameSet: Reading %d (0x%X) bytes of data from byte "
+                       "pos %d (0x%X)" % (frameHeader.dataSize,
+                                          frameHeader.dataSize,
+                                          tagBuffer.tell(),
+                                          tagBuffer.tell()));
+             data = tagBuffer.read(frameHeader.dataSize);
+             TRACE_MSG("FrameSet: %d bytes of data read" % len(data));
 
-         self.addFrame(createFrame(frameHeader, data));
+             self.addFrame(createFrame(frameHeader, data));
 
          # Each frame contains dataSize + headerSize bytes.
          sizeLeft -= (frameHeader.FRAME_HEADER_SIZE + frameHeader.dataSize);
