@@ -1,6 +1,6 @@
 ###############################################################################
 #
-#  Copyright (C) 2002-2006  Travis Shirk <travis@pobox.com>
+#  Copyright (C) 2002-2007  Travis Shirk <travis@pobox.com>
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -1191,14 +1191,21 @@ class Tag:
             TRACE_MSG("Current tag padding: %d" % currPadding);
 
       # Tag it!
+
+      # Set the tagging time
+      t = time.strftime("%Y-%m-%dT%H:%M:%S", time.gmtime());
+      # TDTG for 2.4
       if self.header.minorVersion == 4:
           h = FrameHeader(self.header);
           h.id = "TDTG";
-          t = time.strftime("%Y-%m-%dT%H:%M:%S");
           dateFrame = DateFrame(h, date_str = self.strToUnicode(t),
                                 encoding = self.encoding);
           self.frames.removeFramesByID("TDTG");
           self.frames.addFrame(dateFrame);
+      # TXXX (Tagging time) for older versions
+      else:
+          self.frames.removeFramesByID("TDTG");
+          self.addUserTextFrame('Tagging time', t)
 
       # Render all frames first so the data size is known for the tag header.
       frameData = "";
